import axios from 'axios'

const baseURL = '/api'

const api = axios.create({
  baseURL,
  timeout: 5000,
  withCredentials: true
})

export default {
  // 手机号登录
  loginByPhone(phone, password) {
    return api.post(`/login/cellphone`, {
      phone,
      password
    })
  },

  // 邮箱登录
  loginByEmail(email, password) {
    return api.post(`/login`, {
      email,
      password
    })
  },

  // 二维码登录 - Step 1: 获取 key
  getQrKey() {
    return api.get('/login/qr/key')
  },

  // 二维码登录 - Step 2: 获取二维码
  getQrCode(key) {
    return api.get('/login/qr/create', {
      params: {
        key,
        qrimg: true
      }
    })
  },

  // 二维码登录 - Step 3: 检查扫码状态
  checkQrStatus(key) {
    return api.get('/login/qr/check', {
      params: { key }
    })
  },

  // 获取登录状态
  getLoginStatus() {
    return api.get('/login/status')
  },

  // 获取歌曲 URL
  getSongUrl(id) {
    return api.get(`/song/url`, {
      params: {
        id
      }
    })
  },

  // 获取歌词
  getLyric(id) {
    return api.get(`/lyric`, {
      params: {
        id
      }
    })
  },

  // 获取歌曲详情
  getSongDetail(id) {
    return api.get(`/song/detail`, {
      params: {
        ids: id
      }
    })
  }
} 