import request from '../utils/request'

const BASE_URL = 'http://121.41.171.43:3010' // 修改为正确的基础URL

export default {
  // 手机号登录
  loginByPhone(phone, password) {
    return request('/login/cellphone', {
      method: 'POST',
      data: {
        phone,
        password,
        timestamp: Date.now()
      }
    })
  },

  // 获取二维码 key
  getQrKey() {
    return request('/login/qr/key', {
      method: 'GET',
      data: {
        timestamp: Date.now()
      }
    })
  },

  // 获取二维码
  getQrCode(key) {
    return request('/login/qr/create', {
      method: 'GET',
      data: {
        key,
        qrimg: true,
        timestamp: Date.now()
      }
    })
  },

  // 检查二维码状态
  checkQrStatus(key) {
    return request('/login/qr/check', {
      method: 'GET',
      data: {
        key,
        timestamp: Date.now()
      }
    })
  },

  // 获取歌曲 URL
  getSongUrl(id) {
    return request(`/song/url?id=${id}`)
  },

  // 获取歌词
  getLyric(id) {
    return request(`/lyric?id=${id}`)
  },

  // 获取歌单详情 - 使用简单的查询参数格式
  getPlaylistDetail(id) {
    return request(`/playlist/detail?id=${id}`)
  },

  // 获取歌曲详情
  getSongDetail(ids) {
    // 如果是数组，转换为逗号分隔的字符串
    const idsStr = Array.isArray(ids) ? ids.join(',') : ids
    return request(`/song/detail?ids=${idsStr}`)
  },

  // 获取轮播图
  getBanners() {
    return request('/banner')
  },

  // 获取推荐歌单
  getRecommendPlaylists() {
    return request('/personalized')
  },

  // 获取新歌
  getNewSongs() {
    return request('/personalized/newsong')
  },

  // 获取用户歌单
  getUserPlaylists(uid) {
    return request(`/user/playlist?uid=${uid}`)
  },

  // 获取喜欢的音乐
  getLikedSongs(uid) {
    return request(`/likelist?uid=${uid}`)
  },

  // 获取喜欢的音乐 ID 列表
  getLikedSongIds() {
    return request('/likelist', {
      uid: '93245500',  // 注意：参数值需要是字符串
      timestamp: Date.now()
    })
  },

  // 获取最近播放
  getRecentPlayed(uid) {
    return request('/user/record?uid=' + uid + '&type=1')
  },

  // 获取用户账号信息
  getUserAccount() {
    return request('/user/account')
  },

  // 获取用户详情
  getUserDetail(uid) {
    return request(`/user/detail?uid=${uid}`)
  },

  // 获取用户播放记录
  getUserRecord(uid, type = 1) {  // type=1 最近一周, type=0 所有时间
    return request(`/user/record?uid=${uid}&type=${type}`)
  }
} 