import musicApi from '../../api/music'

Page({
  data: {
    currentSong: {},
    isPlaying: false,
    playlist: [],
    loading: false
  },

  onLoad() {
    // 从本地存储恢复播放列表
    const playlist = wx.getStorageSync('playlist') || []
    const currentSong = wx.getStorageSync('currentSong') || {}
    
    this.setData({
      playlist,
      currentSong
    })

    const playlistId = '3778678'
    this.loadPlaylist(playlistId)
  },

  async loadPlaylist(id) {
    try {
      this.setData({ loading: true })
      const res = await musicApi.getPlaylistDetail(id)
      if (res.data.code === 200 && res.data.playlist) {
        this.setData({
          playlist: res.data.playlist.tracks || []
        })
      } else {
        throw new Error('获取歌单失败')
      }
    } catch (error) {
      console.error('加载歌单失败:', error)
      wx.showToast({
        title: '加载失败',
        icon: 'none'
      })
    } finally {
      this.setData({ loading: false })
    }
  },

  async handlePlay(e) {
    const { song } = e.detail
    try {
      const res = await musicApi.getSongUrl(song.id)
      if (res.data.code === 200 && res.data.data[0]?.url) {
        const songWithUrl = {
          ...song,
          url: res.data.data[0].url
        }
        
        // 更新播放列表
        let playlist = [...this.data.playlist]
        if (!playlist.find(item => item.id === song.id)) {
          playlist.push(song)
          // 保存到本地存储
          wx.setStorageSync('playlist', playlist)
        }
        
        this.setData({
          currentSong: songWithUrl,
          isPlaying: true,
          playlist
        })
        
        // 保存当前播放歌曲
        wx.setStorageSync('currentSong', songWithUrl)
        
        // 播放音乐
        const bgAudio = wx.getBackgroundAudioManager()
        bgAudio.title = song.name
        bgAudio.singer = this.getArtists(song.ar)
        bgAudio.coverImgUrl = song.al?.picUrl
        bgAudio.src = songWithUrl.url
      }
    } catch (error) {
      console.error('播放失败:', error)
      wx.showToast({
        title: '播放失败',
        icon: 'none'
      })
    }
  },

  handleTogglePlay() {
    this.setData({
      isPlaying: !this.data.isPlaying
    })
  },

  handlePlaylistClear() {
    this.setData({
      playlist: []
    })
    wx.setStorageSync('playlist', [])
  },

  handlePlaylistRemove(e) {
    const { index } = e.detail
    const playlist = [...this.data.playlist]
    playlist.splice(index, 1)
    this.setData({ playlist })
    wx.setStorageSync('playlist', playlist)
  },

  onUnload() {
    // 页面卸载时保存状态
    wx.setStorageSync('playlist', this.data.playlist)
    wx.setStorageSync('currentSong', this.data.currentSong)
  }
}) 