import musicApi from '../../api/music'

Page({
  data: {
    qrUrl: '',
    qrKey: '',
    checkTimer: null,
    loading: false
  },

  onLoad() {
    this.getQrCode()
  },

  async getQrCode() {
    try {
      this.setData({ loading: true })
      const keyRes = await musicApi.getQrKey()
      if (keyRes.data.code === 200) {
        const key = keyRes.data.data.unikey
        const qrRes = await musicApi.getQrCode(key)
        if (qrRes.data.code === 200) {
          this.setData({
            qrUrl: qrRes.data.data.qrimg,
            qrKey: key
          })
          this.startCheck()
        }
      }
    } catch (error) {
      console.error('获取二维码失败:', error)
      wx.showToast({
        title: '获取二维码失败',
        icon: 'none'
      })
    } finally {
      this.setData({ loading: false })
    }
  },

  startCheck() {
    this.data.checkTimer = setInterval(async () => {
      try {
        const res = await musicApi.checkQrStatus(this.data.qrKey)
        if (res.data.code === 803) {
          // 登录成功
          clearInterval(this.data.checkTimer)
          wx.showToast({
            title: '登录成功',
            icon: 'success'
          })
          setTimeout(() => {
            wx.navigateBack()
          }, 1500)
        }
      } catch (error) {
        console.error('检查二维码状态失败:', error)
      }
    }, 3000)
  },

  onUnload() {
    if (this.data.checkTimer) {
      clearInterval(this.data.checkTimer)
    }
  }
}) 